#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    Tuple,
)

from cmk.gui.plugins.wato import (
    rulespec_registry,
    RulespecGroupCheckParametersApplications,
    CheckParameterRulespecWithoutItem,
    CheckParameterRulespecWithItem,
)

elementstpl = [
        (
            "upper",
            Tuple(
                title=_("Upper limits"),
                help=_("Upper levels"),
                elements=[
                    Integer(title=_("Warning at")),
                    Integer(title=_("Critical at")),
                ],
            ),
        ),
        (
            "lower",
            Tuple(
                title=_("Lower limits"),
                help=_("Lower levels"),
                elements=[
                    Integer(title=_("Warning below")),
                    Integer(title=_("Critical below")),
                ],
            ),
        ),
    ]


def _valuespec_mshpc_jobs():
    return Dictionary(
        elements=[
            (
                "jobs_canceled",
                Dictionary(
                    title=_("Canceled Jobs"),
                    elements=elementstpl,
                ),
            ),
            (
                "jobs_configuring",
                Dictionary(
                    title=_("Configuring Jobs"),
                    elements=elementstpl,
                ),
            ),
            (
                "jobs_failed",
                Dictionary(
                    title=_("Failed Jobs"),
                    elements=elementstpl,
                ),
            ),
            (
                "jobs_queued",
                Dictionary(
                    title=_("Queued Jobs"),
                    elements=elementstpl,
                ),
            ),
            (
                "jobs_running",
                Dictionary(
                    title=_("Running Jobs"),
                    elements=elementstpl,
                ),
            ),
        ]
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="mshpc_jobs",
        group=RulespecGroupCheckParametersApplications,
        parameter_valuespec=_valuespec_mshpc_jobs,
        title=lambda: _("MSHPC Jobs"),
        match_type="dict",
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="mshpc_jobtemplate",
        group=RulespecGroupCheckParametersApplications,
        parameter_valuespec=_valuespec_mshpc_jobs,
        title=lambda: _("MSHPC Jobtemplate"),
        match_type="dict",
        item_spec=lambda: TextUnicode(
            title=_("Template Name"),
        ),
    )
)
